Module utils
onionize
0.1.2
Module utils
Module Items
Functions
In crate onionize
onionize
Module
utils
Functions

setup_
locale
Sets up the locale for internationalization based on environment variables and system settings with fuzzy matching to select the best available locale. Falls back to English if no suitable locale is found.